==> huaweicloudsdkkafka-3.0.53-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/show_coordinators_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowCoordinatorsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'coordinators': 'list[ShowCoordinatorsRespCoordinators]'
    }

    attribute_map = {
        'coordinators': 'coordinators'
    }

    def __init__(self, coordinators=None):
        """ShowCoordinatorsResponse - a model defined in huaweicloud sdk"""
        
        super(ShowCoordinatorsResponse, self).__init__()

        self._coordinators = None
        self.discriminator = None

        if coordinators is not None:
            self.coordinators = coordinators

    @property
    def coordinators(self):
        """Gets the coordinators of this ShowCoordinatorsResponse.

        所有消费组对应的协调器列表。

        :return: The coordinators of this ShowCoordinatorsResponse.
        :rtype: list[ShowCoordinatorsRespCoordinators]
        """
        return self._coordinators

    @coordinators.setter
    def coordinators(self, coordinators):
        """Sets the coordinators of this ShowCoordinatorsResponse.

        所有消费组对应的协调器列表。

        :param coordinators: The coordinators of this ShowCoordinatorsResponse.
        :type: list[ShowCoordinatorsRespCoordinators]
        """
        self._coordinators = coordinators

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCoordinatorsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkafka-3.0.80-py2.py3-none-any.whl: huaweicloudsdkkafka/v2/model/show_coordinators_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowCoordinatorsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'coordinators': 'list[ShowCoordinatorsRespCoordinators]'
    }

    attribute_map = {
        'coordinators': 'coordinators'
    }

    def __init__(self, coordinators=None):
        """ShowCoordinatorsResponse - a model defined in huaweicloud sdk"""
        
        super(ShowCoordinatorsResponse, self).__init__()

        self._coordinators = None
        self.discriminator = None

        if coordinators is not None:
            self.coordinators = coordinators

    @property
    def coordinators(self):
        """Gets the coordinators of this ShowCoordinatorsResponse.

        所有消费组对应的协调器列表。

        :return: The coordinators of this ShowCoordinatorsResponse.
        :rtype: list[ShowCoordinatorsRespCoordinators]
        """
        return self._coordinators

    @coordinators.setter
    def coordinators(self, coordinators):
        """Sets the coordinators of this ShowCoordinatorsResponse.

        所有消费组对应的协调器列表。

        :param coordinators: The coordinators of this ShowCoordinatorsResponse.
        :type: list[ShowCoordinatorsRespCoordinators]
        """
        self._coordinators = coordinators

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowCoordinatorsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
